#[non_exhaustive]pub enum ErrorKind {
UnclosedBrace,
UnclosedBracket,
TrailingBackslash,
BraceNestingTooDeep,
}Expand description
The kind of invalid construct described by an Error.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
UnclosedBrace
A { is never closed by a matching }.
UnclosedBracket
A [ is never closed by a matching ].
TrailingBackslash
A \ at the end of the pattern has no character to escape.
BraceNestingTooDeep
Brace expansions nest deeper than the supported 10 levels.