pub struct Error {
pub kind: ErrorKind,
pub index: usize,
}Expand description
An error describing why a glob pattern is invalid, returned by validate.
Fields
kind: ErrorKindThe kind of invalid construct that was found.
index: usizeByte offset in the pattern of the offending character.